# BagS'Y

BagS'Y (pronounced [[ba]](https://en.wikipedia.org/wiki/International_Phonetic_Alphabet)) is a python cli tool to
help in the creation, convertion and sharing of rosbags.

It is maintained by the SyRRo team of the U2IS (ENSTA, Paris campus).

## Installation

It is recommended to use [pipx](https://github.com/pypa/pipx). With pipx, to install do `pipx install toolsy`.

Otherwise, you can install it in a python virtual environment.

## Usage

- `bagsy`: print `Hello, World!`

## License

See [LICENSE](LICENSE)